# ParagraphBorder

A border around a paragraph.

**Type:** object

## Properties

- **color** ([OptionalColor](optionalcolor.md)): The color of the border.
- **width** ([Dimension](dimension.md)): The width of the border.
- **padding** ([Dimension](dimension.md)): The padding of the border.
- **dashStyle** (enum): The dash style of the border.
